clear
cap log c
log using mergeMunicipalitiesFUAs.log, replace
cd geodata

**********************************************************************************************************************************************
***** this programme merges municipality/NUTS3 data and FUA definitions and creates geographical areas based on FUAs and NUTS3 classifications
**********************************************************************************************************************************************

**********************************************************
****** first step: input FUA data and drop other countries
**********************************************************

clear
import excel using list-of-municipalities-in-functional-urban-areas.xls, cellrange(A1:H17938) sheet("list_mun") firstrow
* keep your own country
keep if ISO3=="FRA"
* generate standardised French municipality codes (this step will obviously differ in other countries)
ge codgeo_num=substr(IDMunicipality, 3, 5)
label var codgeo_num "code of municipality"
replace codgeo_num=subinstr(codgeo_num,"A","0",1)
replace codgeo_num=subinstr(codgeo_num,"B","0",1)
* generate FUA numerical codes and rename alphanumeric codes
ge fua=real(substr(CODEoffunctionalurbanarea, 3, 3))
ren CODEoffunctionalurbanarea codefua
* keeping also names (in order to be able to collapse within-municipality divisions for Paris) and  saving
keep codgeo_num fua codefua Name*
replace Namemun="Paris" if substr(Namemu, 1,6)=="Paris "
duplicates drop
sort codgeo_num
save interdata\FUA, replace


********************************************************************
****** second step: merge FUA data and municipality and cantons data
********************************************************************
* this uploads a dataset including "official cantons" from an INSEE database and merge it with data for true municipalities (codes, names, NUTS3 regions) 


use cantons, clear

* merge together cantons which have at least one municipality in common (large cantons)
ge ct1=cheflieu if indic_cheflieu==1
encode ct1, ge(ct2)
egen ct_large=mean(ct2), by(dep ct)

* create a database at the municipality level 
collapse ar, by(dep mun cheflieu ct_large)

ge str5 codgeo_num=cheflieu
replace codgeo_num=subinstr(codgeo_num,"A","0",1)
replace codgeo_num=subinstr(codgeo_num,"B","0",1)

sort codgeo_num

label var codgeo_num "code of municipality"

* merge with the FUA datatbase via municipality codes

sort codgeo_num
merge 1:1 codgeo_num using interdata\FUA
* I get some municipalities that are in the FUA database but not in my municipality data
* after checking in databases of the French governments, we found that these have been aggregated to other municipalities 
* I manually check I have everything and drop the municipalities that do not merge (I do not need their codes)
drop if _m==2 
* building a tracker of possible errors in the merge in the case there were a change in the source dataset in the future
ren _merge mergefua


********************************************************************************
****** third step: creation of geographical area based on FUAs and NUTS3 regions
********************************************************************************

* NUTS3 regions
label var dep "Departements (NUTS3 regions)"

* fua1: real FUA only
ge fua1=codefua

* FUAs + NUTS3 regions where no municipality is part of a FUA
egen minfua=min(fua), by(dep)
ge nutsno=codefua
replace nutsno=dep if fua==.&minfua==.


*fuaX: FUAs + rest of NUTS3 if covering at least 70% of municipalities (Extended FUAs)
ge du=(nutsno!="") // dummy for municipalities that are neither in FUAs nor in NUTS3 regions where no municipality is part of a FUA

egen ratiocomfua=mean(du), by(dep) // compute the fraction of municipalities that are not in a FUA
ge fuaX=nutsno
replace fuaX=dep if fuaX==""&ratiocomfua<.3


* change name of municipality identifier to be matchable with social security data (this is specific of French data. In another country it may be sufficient to set "ge comt=codgeo_num")
ge comt=dep+mun 

* compressing, cleaning 
compress
keep dep comt ct_large fu* Name* /*CORE1 ze2010*/ /* ct_large - cantons - exists only in FRA */ // keep essential variables

sort comt
save interdata\mergedMunicipalitiesFUAs, replace

* as fua1 is a subset of fuaX, 
* it is useful to construct a mapping between these different classifications
* In this way HHIs can be constructed only for the most extensive classification (fuaX) to save computation time
* Then using this map, to obtain HHIs under fua1 it is enough to restrict the sample to geographical areas where fua1 are defined.
ge pi=1
collapse pi, by(fua1 fuaX)
drop pi
sort fuaX
save interdata\nested_fua, replace

*** import lau1 (cantons: source EU)
clear
import excel using "EU-28_2015.xlsx", sheet("FR") cellrange(A1:E36679) firstr
ren LAU1 lau1
ren LAU2 comt
drop NUTS_3 CHANGE
drop if substr(comt,1,2)>"95"
drop if comt>="75102"&comt<="75120"
replace comt="75056" if comt=="75101"
sort comt
save temp, replace


*** import intercommunalities
clear
import excel using "Intercommunalite-Metropole_au_01-01-2021.xlsx", sheet("Composition_communale") cellrange(A6:D34971) firstr
ren CODGEO comt
drop if substr(comt,1,2)>"95"
sort comt
merge 1:1 comt using interdata\mergedMunicipalitiesFUAs
drop if _m==1
drop _m
drop LIBGEO

* we set an EPCI equal to the department code if the municipality is not part of an EPCI
replace EPCI = dep if substr(EPCI,1,4)=="ZZZZ"|EPCI==""
compress

sort comt
merge 1:1 comt using temp

* using INSEE data on cantons to correct EU's LAU1 cantons
replace lau1="7209" if ct_large==2464&_m==1
replace lau1="6111" if ct_large==2062&_m==1
replace lau1="6119" if ct_large==2053&_m==1
replace lau1="1419" if ct_large==412&_m==1
replace lau1="2517" if ct_large==751&_m==1
replace lau1="2801" if ct_large==845&_m==1
replace lau1="3802" if ct_large==1245&_m==1
replace lau1="5209" if ct_large==1720&_m==1
replace lau1="6004" if ct_large==2016&_m==1
replace lau1="6912" if ct_large==2365&_m==1
replace lau1="7116" if ct_large==2452&_m==1
replace lau1="7301" if ct_large==2500&_m==1
replace lau1="7713" if ct_large==2626&_m==1

drop if _m==2
drop _m

* compressing and saving

compress
sort comt



save interdata\mergedMunicipalitiesOtherFUAs, replace

erase temp.dta

cd ..

*****************************
log c
