********************************************************************************
* Title: 02. Load contracts data.do
* Description: This dofile loads the raw contracts data.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* B. Log
********************************************************************************

	cap log close
	cap log using "$logs\02. Load contracts data $date.log",replace

********************************************************************************
* C. Load raw files
********************************************************************************

	cd "$input"
	forval year=2009/2017 {

		clear		
		local x = substr("`year'",3, .) 	
		
		forval month =1/12 {	
			append using "$raw_contracts\contratosA`x'M`month'.dta" /// Files were previously loaded from txt files and saved in dta format
		}
		save contracts/contratos_`year',replace
		use contracts/contratos_`year'.dta,clear

	/*
	Filters

		0) Drop self-employed workers and non-identified observations
		1) Keep the variables of interest
		2) Drop contracts with mistakes (end<begin)
		3) Group work places within the same municipality
		4) Adapt occupation code (from CNO-94 to CNO-11 and then to ISCO-8)
		5) Drop transfers within the same FIRM
		6) Merge FUAs
	*/

	* Drop self-employed workers and non-identified observations
	*---------------------------------------------------------------------------
	
		** Drop workers hired by self-employed people
		cap keep if EMPLEADOR_AUTONOMO=="0"
		cap keep if EMPLEADOR_AUTONOMO==0
		
		** Drop unknown workers
		drop if ID_ANONIM=="000000000000"

		** Drop workers with a working age below 16 
		cap destring ANO_INICIO ANO_NAC EDAD,replace 		
		drop if EDAD<16
			
		* Create gender and level of education
		cap destring SEXO,replace
		gen women=(SEXO==2)

	* Keep the variables of interest	
	*---------------------------------------------------------------------------		
	keep *_INICIO *_TERMINO OCUPACION ID_ANONIM IDENT_EMPRESA IDENT_CC CNAE_CC ///
			MUNICIPIO_CC HORAS NIVEL_FORMA IDENT_EMPRESA_USUARIA_CONT_ETT women ///
			ANO_NAC NACIONALIDAD_PF PAIS_RESID_PF MUNICIPIO_CENTRO MUNICIPIO_PF ///
			EDAD women CODIGO_CONT

	* Drop contracts with a date of end prior to begin
	*---------------------------------------------------------------------------
	cap destring DIA_INICIO MES_INICIO ANO_INICIO DIA_TERMINO MES_TERMINO ANO_TERMINO,replace 
	
	cap drop DATE_BEGIN
	gen DATE_BEGIN=mdy(MES_INICIO,DIA_INICIO,ANO_INICIO)

	cap drop DATE_END
	gen DATE_END=mdy(MES_TERMINO,DIA_TERMINO,ANO_TERMINO)

	replace DATE_END=d(31dec2999) if missing(DATE_END) /*Assume endless contracts have as date of end Dec,31th 2999*/
	format DATE_BEGIN DATE_END %td

	gen dur=DATE_END-DATE_BEGIN /*Estimate the number of days between those two dates*/
	
		** Generate monthly date variable
		cap drop ANO MES
		gen ANO=year(DATE_BEGIN)
		gen MES=month(DATE_BEGIN)

		gen t=ym(ANO,MES)
		format t %tm

	drop if dur<0

	* Group work places within the same municipality and the same month
	*What we do is using the first and last date period + create and variable that
	*counts how many contracts were whithin the same month
	*---------------------------------------------------------------------------

		** Drop duplicates
		duplicates drop ID_ANONIM MUNICIPIO_CC IDENT_CC IDENT_EMPRESA DATE_BEGIN DATE_END CODIGO_CONT OCUPACION CNAE_CC,force

		** Group obs
		sort ID_ANONIM MUNICIPIO_CC IDENT_EMPRESA IDENT_CC t 

		bys ID_ANONIM MUNICIPIO_CC IDENT_EMPRESA IDENT_CC t: gen dup=_n
		bys ID_ANONIM MUNICIPIO_CC IDENT_EMPRESA IDENT_CC t: egen max_dup=max(dup)
		bys ID_ANONIM MUNICIPIO_CC IDENT_EMPRESA IDENT_CC t: egen min_DB=min(DATE_BEGIN)

		gen drop=DATE_END if DATE_END!=d(31dec2999)
		bys ID_ANONIM MUNICIPIO_CC IDENT_EMPRESA IDENT_CC t: egen DATE_END_ft=max(drop)

			keep if dup==max_dup

		replace DATE_BEGIN=min_DB

		rename (dup IDENT_EMPRESA) (contracts_num workplace)
		drop max_dup min_DB drop

	* Create a CNO type variables
	*---------------------------------------------------------------------------
	qui {
	gen CNO="0011" if OCUPACION=="0010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="0011" if OCUPACION=="0020" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="0012" if OCUPACION=="0030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="0020" if OCUPACION=="0030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1111" if OCUPACION=="1011" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1111" if OCUPACION=="1012" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1111" if OCUPACION=="1013" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1112" if OCUPACION=="1020" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1111" if OCUPACION=="1031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1111" if OCUPACION=="1032" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1113" if OCUPACION=="1041" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1113" if OCUPACION=="1042" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1113" if OCUPACION=="1043" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1120" if OCUPACION=="1110" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1311" if OCUPACION=="1121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1312" if OCUPACION=="1121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1313" if OCUPACION=="1122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1314" if OCUPACION=="1122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1316" if OCUPACION=="1123" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1431" if OCUPACION=="1124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1432" if OCUPACION=="1124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1411" if OCUPACION=="1125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1419" if OCUPACION=="1125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1421" if OCUPACION=="1125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1422" if OCUPACION=="1125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1429" if OCUPACION=="1125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1315" if OCUPACION=="1126" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1321" if OCUPACION=="1126" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1126" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1327" if OCUPACION=="1127" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1219" if OCUPACION=="1128" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1128" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1322" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1323" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1324" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1325" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1326" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1329" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1501" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2934" if OCUPACION=="1129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1211" if OCUPACION=="1131" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1219" if OCUPACION=="1131" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1212" if OCUPACION=="1132" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1221" if OCUPACION=="1133" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1222" if OCUPACION=="1134" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1315" if OCUPACION=="1135" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1321" if OCUPACION=="1136" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1223" if OCUPACION=="1137" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1323" if OCUPACION=="1138" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1219" if OCUPACION=="1139" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1431" if OCUPACION=="1210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1432" if OCUPACION=="1220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5300" if OCUPACION=="1220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1411" if OCUPACION=="1311" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1419" if OCUPACION=="1312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5840" if OCUPACION=="1312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1419" if OCUPACION=="1319" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1421" if OCUPACION=="1320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1422" if OCUPACION=="1320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1429" if OCUPACION=="1320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5000" if OCUPACION=="1320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1311" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1312" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6110" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6120" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6201" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6202" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6203" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6204" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6205" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6300" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6410" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6421" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6422" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6423" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6430" if OCUPACION=="1401" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1313" if OCUPACION=="1402" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1314" if OCUPACION=="1402" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1316" if OCUPACION=="1403" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1315" if OCUPACION=="1404" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1404" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1321" if OCUPACION=="1405" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1327" if OCUPACION=="1405" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1329" if OCUPACION=="1405" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1405" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1406" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1322" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1323" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1324" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1325" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1326" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1329" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1501" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1409" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1431" if OCUPACION=="1510" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5300" if OCUPACION=="1520" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5411" if OCUPACION=="1520" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5840" if OCUPACION=="1611" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5840" if OCUPACION=="1612" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5840" if OCUPACION=="1619" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5000" if OCUPACION=="1620" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6110" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6120" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6201" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6202" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6203" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6204" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6205" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6300" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6410" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6421" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6422" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6430" if OCUPACION=="1701" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1313" if OCUPACION=="1702" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1314" if OCUPACION=="1702" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1316" if OCUPACION=="1703" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1315" if OCUPACION=="1704" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1704" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1321" if OCUPACION=="1705" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1327" if OCUPACION=="1705" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1706" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1322" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1323" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1324" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1325" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1326" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1329" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1501" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="1509" if OCUPACION=="1709" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2411" if OCUPACION=="2011" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2412" if OCUPACION=="2012" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2413" if OCUPACION=="2013" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2414" if OCUPACION=="2014" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2415" if OCUPACION=="2021" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2416" if OCUPACION=="2022" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2711" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2712" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2713" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2721" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2722" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2723" if OCUPACION=="2031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2719" if OCUPACION=="2039" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2729" if OCUPACION=="2039" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2451" if OCUPACION=="2040" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2452" if OCUPACION=="2040" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2453" if OCUPACION=="2040" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2432" if OCUPACION=="2051" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2441" if OCUPACION=="2052" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2442" if OCUPACION=="2053" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2443" if OCUPACION=="2053" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2433" if OCUPACION=="2054" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2434" if OCUPACION=="2054" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2435" if OCUPACION=="2055" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2436" if OCUPACION=="2056" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2436" if OCUPACION=="2057" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2454" if OCUPACION=="2058" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2431" if OCUPACION=="2059" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2437" if OCUPACION=="2059" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2439" if OCUPACION=="2059" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2421" if OCUPACION=="2111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2426" if OCUPACION=="2111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2130" if OCUPACION=="2112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2158" if OCUPACION=="2112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2421" if OCUPACION=="2112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2422" if OCUPACION=="2113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2423" if OCUPACION=="2113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2427" if OCUPACION=="2113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2111" if OCUPACION=="2121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2112" if OCUPACION=="2121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2151" if OCUPACION=="2122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2130" if OCUPACION=="2130" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2140" if OCUPACION=="2140" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2159" if OCUPACION=="2190" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2210" if OCUPACION=="2210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2230" if OCUPACION=="2220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2321" if OCUPACION=="2231" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2321" if OCUPACION=="2232" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2322" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2323" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2324" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2325" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2326" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2329" if OCUPACION=="2239" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2511" if OCUPACION=="2311" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2512" if OCUPACION=="2312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2513" if OCUPACION=="2320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2591" if OCUPACION=="2391" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2591" if OCUPACION=="2392" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2592" if OCUPACION=="2393" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2599" if OCUPACION=="2399" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2611" if OCUPACION=="2411" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2624" if OCUPACION=="2412" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2625" if OCUPACION=="2412" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2651" if OCUPACION=="2413" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2652" if OCUPACION=="2413" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2612" if OCUPACION=="2419" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2613" if OCUPACION=="2419" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2621" if OCUPACION=="2419" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2622" if OCUPACION=="2419" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2651" if OCUPACION=="2419" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2810" if OCUPACION=="2420" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2821" if OCUPACION=="2431" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2822" if OCUPACION=="2432" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2923" if OCUPACION=="2433" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2159" if OCUPACION=="2434" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2823" if OCUPACION=="2434" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2921" if OCUPACION=="2511" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2922" if OCUPACION=="2511" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2931" if OCUPACION=="2512" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2932" if OCUPACION=="2513" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2933" if OCUPACION=="2514" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2934" if OCUPACION=="2515" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2935" if OCUPACION=="2515" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3739" if OCUPACION=="2515" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2911" if OCUPACION=="2521" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2912" if OCUPACION=="2522" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2623" if OCUPACION=="2530" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2411" if OCUPACION=="2611" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2412" if OCUPACION=="2612" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2413" if OCUPACION=="2613" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2414" if OCUPACION=="2614" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2415" if OCUPACION=="2621" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2416" if OCUPACION=="2622" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2712" if OCUPACION=="2631" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2721" if OCUPACION=="2631" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2723" if OCUPACION=="2631" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2713" if OCUPACION=="2639" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2722" if OCUPACION=="2639" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2481" if OCUPACION=="2640" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2462" if OCUPACION=="2651" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2471" if OCUPACION=="2652" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2472" if OCUPACION=="2653" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2473" if OCUPACION=="2653" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2463" if OCUPACION=="2654" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2464" if OCUPACION=="2654" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2465" if OCUPACION=="2655" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2466" if OCUPACION=="2656" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2483" if OCUPACION=="2657" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2461" if OCUPACION=="2659" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2469" if OCUPACION=="2659" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2421" if OCUPACION=="2711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2426" if OCUPACION=="2711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2424" if OCUPACION=="2712" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2425" if OCUPACION=="2712" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2121" if OCUPACION=="2720" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2122" if OCUPACION=="2720" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2123" if OCUPACION=="2720" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2240" if OCUPACION=="2811" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2251" if OCUPACION=="2812" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2311" if OCUPACION=="2820" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2220" if OCUPACION=="2831" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2220" if OCUPACION=="2839" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2611" if OCUPACION=="2911" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2624" if OCUPACION=="2912" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2625" if OCUPACION=="2912" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2622" if OCUPACION=="2913" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2630" if OCUPACION=="2913" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2911" if OCUPACION=="2921" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3322" if OCUPACION=="2921" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2912" if OCUPACION=="2922" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2824" if OCUPACION=="2931" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2824" if OCUPACION=="2939" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2825" if OCUPACION=="2939" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2830" if OCUPACION=="2940" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2623" if OCUPACION=="2950" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3110" if OCUPACION=="3010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3121" if OCUPACION=="3021" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3122" if OCUPACION=="3022" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3123" if OCUPACION=="3023" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3124" if OCUPACION=="3024" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3125" if OCUPACION=="3024" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3833" if OCUPACION=="3024" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3126" if OCUPACION=="3025" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3127" if OCUPACION=="3026" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3134" if OCUPACION=="3026" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3128" if OCUPACION=="3027" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3129" if OCUPACION=="3029" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3811" if OCUPACION=="3031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3812" if OCUPACION=="3031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3813" if OCUPACION=="3031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3814" if OCUPACION=="3031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3820" if OCUPACION=="3031" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="3032" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3731" if OCUPACION=="3041" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3831" if OCUPACION=="3041" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3831" if OCUPACION=="3042" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3832" if OCUPACION=="3042" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3833" if OCUPACION=="3042" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3311" if OCUPACION=="3043" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3312" if OCUPACION=="3043" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3317" if OCUPACION=="3043" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3129" if OCUPACION=="3049" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3151" if OCUPACION=="3051" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3152" if OCUPACION=="3052" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3153" if OCUPACION=="3061" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3154" if OCUPACION=="3062" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3155" if OCUPACION=="3063" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3122" if OCUPACION=="3071" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2158" if OCUPACION=="3072" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3326" if OCUPACION=="3072" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3160" if OCUPACION=="3073" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3326" if OCUPACION=="3073" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3141" if OCUPACION=="3111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3142" if OCUPACION=="3112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3143" if OCUPACION=="3112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3142" if OCUPACION=="3113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3143" if OCUPACION=="3113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3313" if OCUPACION=="3121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3314" if OCUPACION=="3121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3327" if OCUPACION=="3122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3326" if OCUPACION=="3123" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3316" if OCUPACION=="3124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3321" if OCUPACION=="3124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5621" if OCUPACION=="3125" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3317" if OCUPACION=="3129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3329" if OCUPACION=="3129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3331" if OCUPACION=="3129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3339" if OCUPACION=="3129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2153" if OCUPACION=="3131" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3323" if OCUPACION=="3131" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2155" if OCUPACION=="3132" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3324" if OCUPACION=="3132" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2152" if OCUPACION=="3133" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3315" if OCUPACION=="3133" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3325" if OCUPACION=="3133" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3329" if OCUPACION=="3133" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2156" if OCUPACION=="3134" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2154" if OCUPACION=="3135" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2157" if OCUPACION=="3136" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2252" if OCUPACION=="3211" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2312" if OCUPACION=="3212" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3153" if OCUPACION=="3220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3723" if OCUPACION=="3220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5894" if OCUPACION=="3220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3401" if OCUPACION=="3311" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3521" if OCUPACION=="3312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3534" if OCUPACION=="3313" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3532" if OCUPACION=="3314" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4421" if OCUPACION=="3314" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3405" if OCUPACION=="3315" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3539" if OCUPACION=="3315" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3522" if OCUPACION=="3316" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3402" if OCUPACION=="3319" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2640" if OCUPACION=="3320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2653" if OCUPACION=="3320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3510" if OCUPACION=="3320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3612" if OCUPACION=="3411" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3613" if OCUPACION=="3411" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3711" if OCUPACION=="3412" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3403" if OCUPACION=="3413" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3404" if OCUPACION=="3414" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3531" if OCUPACION=="3421" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3621" if OCUPACION=="3422" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3622" if OCUPACION=="3423" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3623" if OCUPACION=="3424" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3629" if OCUPACION=="3429" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3523" if OCUPACION=="3511" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3531" if OCUPACION=="3512" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3533" if OCUPACION=="3513" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3535" if OCUPACION=="3519" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3539" if OCUPACION=="3519" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3631" if OCUPACION=="3521" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3632" if OCUPACION=="3522" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3712" if OCUPACION=="3523" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2824" if OCUPACION=="3531" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3713" if OCUPACION=="3531" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3715" if OCUPACION=="3532" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3724" if OCUPACION=="3532" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3713" if OCUPACION=="3539" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3714" if OCUPACION=="3539" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2482" if OCUPACION=="3541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2484" if OCUPACION=="3541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3732" if OCUPACION=="3541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3739" if OCUPACION=="3541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7616" if OCUPACION=="3541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2936" if OCUPACION=="3542" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2932" if OCUPACION=="3543" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2933" if OCUPACION=="3543" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2939" if OCUPACION=="3544" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3721" if OCUPACION=="3545" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3722" if OCUPACION=="3545" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3723" if OCUPACION=="3545" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="2937" if OCUPACION=="3546" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3716" if OCUPACION=="3550" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4111" if OCUPACION=="4011" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4112" if OCUPACION=="4011" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4113" if OCUPACION=="4012" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4121" if OCUPACION=="4021" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4122" if OCUPACION=="4022" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4123" if OCUPACION=="4023" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3733" if OCUPACION=="4101" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4210" if OCUPACION=="4101" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4221" if OCUPACION=="4102" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4430" if OCUPACION=="4103" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4222" if OCUPACION=="4104" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4222" if OCUPACION=="4105" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4301" if OCUPACION=="4210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4301" if OCUPACION=="4220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3611" if OCUPACION=="4300" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3612" if OCUPACION=="4300" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3614" if OCUPACION=="4300" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4223" if OCUPACION=="4300" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4309" if OCUPACION=="4300" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4500" if OCUPACION=="4400" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4411" if OCUPACION=="4510" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4412" if OCUPACION=="4510" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4424" if OCUPACION=="4510" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4421" if OCUPACION=="4521" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4412" if OCUPACION=="4522" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4422" if OCUPACION=="4522" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4423" if OCUPACION=="4523" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5500" if OCUPACION=="4601" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4441" if OCUPACION=="4602" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4446" if OCUPACION=="4602" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4442" if OCUPACION=="4603" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4443" if OCUPACION=="4603" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4444" if OCUPACION=="4604" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="4445" if OCUPACION=="4605" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5110" if OCUPACION=="5010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9320" if OCUPACION=="5010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5120" if OCUPACION=="5020" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3734" if OCUPACION=="5030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5110" if OCUPACION=="5030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5120" if OCUPACION=="5030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5611" if OCUPACION=="5111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5612" if OCUPACION=="5112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5629" if OCUPACION=="5112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5710" if OCUPACION=="5113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5721" if OCUPACION=="5121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5722" if OCUPACION=="5121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5622" if OCUPACION=="5129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5629" if OCUPACION=="5129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5893" if OCUPACION=="5129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5811" if OCUPACION=="5130" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5812" if OCUPACION=="5130" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5821" if OCUPACION=="5141" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5822" if OCUPACION=="5142" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3724" if OCUPACION=="5143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5821" if OCUPACION=="5143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5823" if OCUPACION=="5143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5824" if OCUPACION=="5143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5825" if OCUPACION=="5143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5831" if OCUPACION=="5150" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5832" if OCUPACION=="5150" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5891" if OCUPACION=="5191" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5892" if OCUPACION=="5192" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3724" if OCUPACION=="5199" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5895" if OCUPACION=="5199" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5899" if OCUPACION=="5199" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5910" if OCUPACION=="5210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5921" if OCUPACION=="5221" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5922" if OCUPACION=="5222" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5923" if OCUPACION=="5223" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5931" if OCUPACION=="5230" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5932" if OCUPACION=="5230" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5991" if OCUPACION=="5240" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5941" if OCUPACION=="5250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5942" if OCUPACION=="5250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5992" if OCUPACION=="5291" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5993" if OCUPACION=="5299" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5999" if OCUPACION=="5299" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5493" if OCUPACION=="5310" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5210" if OCUPACION=="5320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5220" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5411" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5412" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5430" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5492" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5499" if OCUPACION=="5330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6110" if OCUPACION=="6011" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6120" if OCUPACION=="6012" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6110" if OCUPACION=="6021" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6120" if OCUPACION=="6022" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6201" if OCUPACION=="6111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6202" if OCUPACION=="6111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6203" if OCUPACION=="6111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="6111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6205" if OCUPACION=="6112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5893" if OCUPACION=="6119" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6204" if OCUPACION=="6119" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="6119" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6201" if OCUPACION=="6121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6202" if OCUPACION=="6121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6203" if OCUPACION=="6121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="6121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6205" if OCUPACION=="6122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5893" if OCUPACION=="6129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6204" if OCUPACION=="6129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6209" if OCUPACION=="6129" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6300" if OCUPACION=="6210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6410" if OCUPACION=="6220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6300" if OCUPACION=="6230" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6410" if OCUPACION=="6241" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6410" if OCUPACION=="6242" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6421" if OCUPACION=="6311" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6422" if OCUPACION=="6312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6423" if OCUPACION=="6313" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6430" if OCUPACION=="6314" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6421" if OCUPACION=="6321" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6422" if OCUPACION=="6322" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6423" if OCUPACION=="6323" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="6430" if OCUPACION=="6324" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3202" if OCUPACION=="7010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3202" if OCUPACION=="7020" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3202" if OCUPACION=="7030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7121" if OCUPACION=="7110" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7111" if OCUPACION=="7120" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7112" if OCUPACION=="7120" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7131" if OCUPACION=="7130" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7132" if OCUPACION=="7130" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7191" if OCUPACION=="7140" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7192" if OCUPACION=="7140" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7193" if OCUPACION=="7140" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7199" if OCUPACION=="7140" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7211" if OCUPACION=="7210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7212" if OCUPACION=="7210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7221" if OCUPACION=="7220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7222" if OCUPACION=="7220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7223" if OCUPACION=="7220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7250" if OCUPACION=="7220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7510" if OCUPACION=="7230" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7231" if OCUPACION=="7240" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7232" if OCUPACION=="7240" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7295" if OCUPACION=="7250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7894" if OCUPACION=="7250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7291" if OCUPACION=="7291" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7240" if OCUPACION=="7292" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7292" if OCUPACION=="7293" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7293" if OCUPACION=="7294" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7294" if OCUPACION=="7299" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3202" if OCUPACION=="7310" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="7310" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7401" if OCUPACION=="7320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7403" if OCUPACION=="7331" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7404" if OCUPACION=="7331" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7402" if OCUPACION=="7332" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7521" if OCUPACION=="7340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7531" if OCUPACION=="7340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7532" if OCUPACION=="7340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7533" if OCUPACION=="7340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3201" if OCUPACION=="7410" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8111" if OCUPACION=="7421" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7892" if OCUPACION=="7422" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7122" if OCUPACION=="7423" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7423" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7311" if OCUPACION=="7511" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7312" if OCUPACION=="7512" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7313" if OCUPACION=="7513" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7314" if OCUPACION=="7514" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7315" if OCUPACION=="7515" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7891" if OCUPACION=="7516" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7321" if OCUPACION=="7521" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7322" if OCUPACION=="7522" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7323" if OCUPACION=="7523" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7324" if OCUPACION=="7524" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7401" if OCUPACION=="7611" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7405" if OCUPACION=="7611" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7402" if OCUPACION=="7612" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7250" if OCUPACION=="7613" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7403" if OCUPACION=="7613" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7404" if OCUPACION=="7613" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7521" if OCUPACION=="7621" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7531" if OCUPACION=="7622" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7532" if OCUPACION=="7622" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7533" if OCUPACION=="7622" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7533" if OCUPACION=="7623" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7522" if OCUPACION=="7624" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3315" if OCUPACION=="7711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3316" if OCUPACION=="7711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3317" if OCUPACION=="7711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7611" if OCUPACION=="7711" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7612" if OCUPACION=="7712" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7613" if OCUPACION=="7713" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7621" if OCUPACION=="7721" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7622" if OCUPACION=="7721" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7621" if OCUPACION=="7722" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7621" if OCUPACION=="7723" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8133" if OCUPACION=="7724" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7623" if OCUPACION=="7725" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7622" if OCUPACION=="7726" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7614" if OCUPACION=="7731" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7731" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7615" if OCUPACION=="7732" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7899" if OCUPACION=="7732" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7616" if OCUPACION=="7733" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7616" if OCUPACION=="7734" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7617" if OCUPACION=="7741" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7619" if OCUPACION=="7741" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7618" if OCUPACION=="7742" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7701" if OCUPACION=="7801" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7702" if OCUPACION=="7801" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7703" if OCUPACION=="7802" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7704" if OCUPACION=="7803" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7705" if OCUPACION=="7804" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7706" if OCUPACION=="7804" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7707" if OCUPACION=="7804" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7709" if OCUPACION=="7805" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7708" if OCUPACION=="7806" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7811" if OCUPACION=="7911" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7911" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7812" if OCUPACION=="7912" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7617" if OCUPACION=="7913" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7820" if OCUPACION=="7920" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7618" if OCUPACION=="7931" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7931" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7618" if OCUPACION=="7932" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7932" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8152" if OCUPACION=="7932" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7831" if OCUPACION=="7933" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7933" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7831" if OCUPACION=="7934" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7832" if OCUPACION=="7935" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7833" if OCUPACION=="7935" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7834" if OCUPACION=="7936" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7835" if OCUPACION=="7937" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7836" if OCUPACION=="7941" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7941" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7837" if OCUPACION=="7942" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7893" if OCUPACION=="7942" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3201" if OCUPACION=="8010" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8020" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8030" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3206" if OCUPACION=="8040" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3204" if OCUPACION=="8050" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3131" if OCUPACION=="8060" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="8070" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8070" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8111" if OCUPACION=="8111" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8112" if OCUPACION=="8112" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8113" if OCUPACION=="8113" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3135" if OCUPACION=="8121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8121" if OCUPACION=="8121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3135" if OCUPACION=="8122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8121" if OCUPACION=="8122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3135" if OCUPACION=="8123" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8121" if OCUPACION=="8123" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3135" if OCUPACION=="8124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8121" if OCUPACION=="8124" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8191" if OCUPACION=="8131" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8191" if OCUPACION=="8139" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8144" if OCUPACION=="8141" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="8142" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8145" if OCUPACION=="8142" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8145" if OCUPACION=="8143" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8151" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3133" if OCUPACION=="8152" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8152" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3133" if OCUPACION=="8153" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8153" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3133" if OCUPACION=="8154" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8154" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3134" if OCUPACION=="8155" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3133" if OCUPACION=="8159" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8159" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3131" if OCUPACION=="8161" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="8162" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8192" if OCUPACION=="8162" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3132" if OCUPACION=="8163" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="8163" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3139" if OCUPACION=="8170" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8210" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3204" if OCUPACION=="8220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3205" if OCUPACION=="8230" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8240" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3206" if OCUPACION=="8250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3207" if OCUPACION=="8250" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8260" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3203" if OCUPACION=="8270" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="3209" if OCUPACION=="8280" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7323" if OCUPACION=="8311" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8114" if OCUPACION=="8312" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8132" if OCUPACION=="8321" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8322" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8122" if OCUPACION=="8323" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8133" if OCUPACION=="8324" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8131" if OCUPACION=="8329" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8141" if OCUPACION=="8331" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8142" if OCUPACION=="8332" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7812" if OCUPACION=="8340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7622" if OCUPACION=="8351" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="7623" if OCUPACION=="8352" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8143" if OCUPACION=="8353" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8151" if OCUPACION=="8361" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8152" if OCUPACION=="8362" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8153" if OCUPACION=="8363" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8154" if OCUPACION=="8364" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8170" if OCUPACION=="8364" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8155" if OCUPACION=="8365" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8156" if OCUPACION=="8366" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8159" if OCUPACION=="8369" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8371" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8371" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8372" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8372" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8373" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8373" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8374" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8374" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8375" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8375" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8376" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8376" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8377" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8377" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8378" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8378" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8160" if OCUPACION=="8379" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8379" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8201" if OCUPACION=="8411" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8202" if OCUPACION=="8412" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8202" if OCUPACION=="8413" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8209" if OCUPACION=="8414" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8209" if OCUPACION=="8415" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8209" if OCUPACION=="8416" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8209" if OCUPACION=="8417" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8193" if OCUPACION=="8490" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8199" if OCUPACION=="8490" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8209" if OCUPACION=="8490" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8311" if OCUPACION=="8511" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8312" if OCUPACION=="8512" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8331" if OCUPACION=="8520" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8332" if OCUPACION=="8520" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8321" if OCUPACION=="8530" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8322" if OCUPACION=="8530" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8331" if OCUPACION=="8541" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8332" if OCUPACION=="8542" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8333" if OCUPACION=="8543" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8340" if OCUPACION=="8550" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8411" if OCUPACION=="8610" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8412" if OCUPACION=="8610" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8420" if OCUPACION=="8620" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8431" if OCUPACION=="8630" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8432" if OCUPACION=="8630" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="8440" if OCUPACION=="8640" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9410" if OCUPACION=="9001" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5420" if OCUPACION=="9002" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5491" if OCUPACION=="9002" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9100" if OCUPACION=="9110" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9210" if OCUPACION=="9121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9310" if OCUPACION=="9121" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9221" if OCUPACION=="9122" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5833" if OCUPACION=="9211" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9222" if OCUPACION=="9212" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9223" if OCUPACION=="9212" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9229" if OCUPACION=="9212" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="5942" if OCUPACION=="9220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9490" if OCUPACION=="9220" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9420" if OCUPACION=="9310" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9431" if OCUPACION=="9320" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9432" if OCUPACION=="9330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9433" if OCUPACION=="9330" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9434" if OCUPACION=="9340" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9441" if OCUPACION=="9351" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9442" if OCUPACION=="9351" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9443" if OCUPACION=="9352" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9490" if OCUPACION=="9352" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9511" if OCUPACION=="9410" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9512" if OCUPACION=="9410" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9520" if OCUPACION=="9420" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9530" if OCUPACION=="9430" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9543" if OCUPACION=="9440" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9541" if OCUPACION=="9450" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9542" if OCUPACION=="9450" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9543" if OCUPACION=="9450" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9603" if OCUPACION=="9500" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9601" if OCUPACION=="9601" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9602" if OCUPACION=="9602" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9442" if OCUPACION=="9700" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9700" if OCUPACION=="9700" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9811" if OCUPACION=="9800" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9812" if OCUPACION=="9800" & inrange(t,m(2009m1),m(2011m12))
	replace CNO="9820" if OCUPACION=="9800" & inrange(t,m(2009m1),m(2011m12))
	}


	if `year'>=2011 {
	replace CNO=OCUPACION if length(CNO)==0
	}


	qui {
	gen OCUP="0110" if CNO=="0011"
	replace OCUP="0210" if CNO=="0012"
	replace OCUP="0310" if CNO=="0020"
	replace OCUP="1111" if CNO=="1111"
	replace OCUP="1112" if CNO=="1112"
	replace OCUP="1114" if CNO=="1113"
	replace OCUP="1120" if CNO=="1120"
	replace OCUP="1211" if CNO=="1211"
	replace OCUP="1212" if CNO=="1212"
	replace OCUP="1213" if CNO=="1219"
	replace OCUP="1219" if CNO=="1219"
	replace OCUP="1221" if CNO=="1221"
	replace OCUP="1222" if CNO=="1222"
	replace OCUP="1223" if CNO=="1223"
	replace OCUP="1311" if CNO=="1311"
	replace OCUP="1312" if CNO=="1312"
	replace OCUP="1321" if CNO=="1313"
	replace OCUP="1322" if CNO=="1314"
	replace OCUP="1324" if CNO=="1315"
	replace OCUP="1323" if CNO=="1316"
	replace OCUP="1330" if CNO=="1321"
	replace OCUP="1341" if CNO=="1322"
	replace OCUP="1342" if CNO=="1323"
	replace OCUP="1343" if CNO=="1324"
	replace OCUP="1344" if CNO=="1325"
	replace OCUP="1345" if CNO=="1326"
	replace OCUP="1346" if CNO=="1327"
	replace OCUP="1349" if CNO=="1329"
	replace OCUP="1411" if CNO=="1411"
	replace OCUP="1411" if CNO=="1419"
	replace OCUP="1412" if CNO=="1421"
	replace OCUP="1412" if CNO=="1422"
	replace OCUP="1412" if CNO=="1429"
	replace OCUP="1420" if CNO=="1431"
	replace OCUP="1420" if CNO=="1432"
	replace OCUP="1431" if CNO=="1501"
	replace OCUP="1439" if CNO=="1509"
	replace OCUP="2211" if CNO=="2111"
	replace OCUP="2212" if CNO=="2112"
	replace OCUP="2221" if CNO=="2121"
	replace OCUP="2221" if CNO=="2122"
	replace OCUP="2222" if CNO=="2123"
	replace OCUP="2250" if CNO=="2130"
	replace OCUP="2262" if CNO=="2140"
	replace OCUP="2261" if CNO=="2151"
	replace OCUP="2264" if CNO=="2152"
	replace OCUP="2265" if CNO=="2153"
	replace OCUP="2266" if CNO=="2154"
	replace OCUP="2267" if CNO=="2155"
	replace OCUP="2269" if CNO=="2156"
	replace OCUP="2269" if CNO=="2157"
	replace OCUP="2263" if CNO=="2158"
	replace OCUP="2269" if CNO=="2159"
	replace OCUP="2634" if CNO=="2159"
	replace OCUP="2310" if CNO=="2210"
	replace OCUP="2320" if CNO=="2220"
	replace OCUP="2330" if CNO=="2230"
	replace OCUP="2341" if CNO=="2240"
	replace OCUP="2342" if CNO=="2251"
	replace OCUP="2342" if CNO=="2252"
	replace OCUP="2352" if CNO=="2311"
	replace OCUP="2352" if CNO=="2312"
	replace OCUP="2351" if CNO=="2321"
	replace OCUP="2353" if CNO=="2322"
	replace OCUP="2354" if CNO=="2323"
	replace OCUP="2355" if CNO=="2323"
	replace OCUP="2355" if CNO=="2324"
	replace OCUP="2356" if CNO=="2325"
	replace OCUP="2359" if CNO=="2326"
	replace OCUP="2359" if CNO=="2329"
	replace OCUP="2111" if CNO=="2411"
	replace OCUP="2112" if CNO=="2412"
	replace OCUP="2113" if CNO=="2413"
	replace OCUP="2114" if CNO=="2414"
	replace OCUP="2120" if CNO=="2415"
	replace OCUP="2120" if CNO=="2416"
	replace OCUP="2131" if CNO=="2421"
	replace OCUP="2132" if CNO=="2422"
	replace OCUP="2132" if CNO=="2423"
	replace OCUP="2132" if CNO=="2424"
	replace OCUP="2132" if CNO=="2425"
	replace OCUP="2133" if CNO=="2426"
	replace OCUP="2132" if CNO=="2427"
	replace OCUP="2141" if CNO=="2431"
	replace OCUP="2142" if CNO=="2432"
	replace OCUP="2144" if CNO=="2433"
	replace OCUP="2144" if CNO=="2434"
	replace OCUP="2145" if CNO=="2435"
	replace OCUP="2146" if CNO=="2436"
	replace OCUP="2143" if CNO=="2437"
	replace OCUP="2149" if CNO=="2439"
	replace OCUP="2151" if CNO=="2441"
	replace OCUP="2152" if CNO=="2442"
	replace OCUP="2153" if CNO=="2443"
	replace OCUP="2161" if CNO=="2451"
	replace OCUP="2162" if CNO=="2452"
	replace OCUP="2164" if CNO=="2453"
	replace OCUP="2165" if CNO=="2454"
	replace OCUP="2141" if CNO=="2461"
	replace OCUP="2142" if CNO=="2462"
	replace OCUP="2144" if CNO=="2463"
	replace OCUP="2144" if CNO=="2464"
	replace OCUP="2145" if CNO=="2465"
	replace OCUP="2146" if CNO=="2466"
	replace OCUP="2149" if CNO=="2469"
	replace OCUP="2151" if CNO=="2471"
	replace OCUP="2152" if CNO=="2472"
	replace OCUP="2153" if CNO=="2473"
	replace OCUP="2164" if CNO=="2481"
	replace OCUP="2161" if CNO=="2481"
	replace OCUP="2163" if CNO=="2482"
	replace OCUP="2165" if CNO=="2483"
	replace OCUP="2166" if CNO=="2484"
	replace OCUP="2611" if CNO=="2511"
	replace OCUP="2611" if CNO=="2512"
	replace OCUP="2612" if CNO=="2513"
	replace OCUP="2619" if CNO=="2591"
	replace OCUP="2619" if CNO=="2592"
	replace OCUP="2619" if CNO=="2599"
	replace OCUP="2411" if CNO=="2611"
	replace OCUP="2412" if CNO=="2612"
	replace OCUP="2413" if CNO=="2613"
	replace OCUP="2421" if CNO=="2621"
	replace OCUP="2422" if CNO=="2622"
	replace OCUP="2422" if CNO=="2623"
	replace OCUP="2423" if CNO=="2624"
	replace OCUP="2424" if CNO=="2625"
	replace OCUP="2422" if CNO=="2630"
	replace OCUP="2433" if CNO=="2640"
	replace OCUP="2431" if CNO=="2651"
	replace OCUP="2432" if CNO=="2652"
	replace OCUP="2434" if CNO=="2653"
	replace OCUP="2511" if CNO=="2711"
	replace OCUP="2512" if CNO=="2712"
	replace OCUP="2514" if CNO=="2712"
	replace OCUP="2513" if CNO=="2713"
	replace OCUP="2519" if CNO=="2719"
	replace OCUP="2521" if CNO=="2721"
	replace OCUP="2522" if CNO=="2722"
	replace OCUP="2523" if CNO=="2723"
	replace OCUP="2529" if CNO=="2729"
	replace OCUP="2631" if CNO=="2810"
	replace OCUP="2632" if CNO=="2821"
	replace OCUP="2633" if CNO=="2822"
	replace OCUP="2634" if CNO=="2823"
	replace OCUP="2635" if CNO=="2824"
	replace OCUP="2635" if CNO=="2825"
	replace OCUP="2636" if CNO=="2830"
	replace OCUP="2621" if CNO=="2911"
	replace OCUP="2622" if CNO=="2912"
	replace OCUP="2641" if CNO=="2921"
	replace OCUP="2642" if CNO=="2922"
	replace OCUP="2643" if CNO=="2923"
	replace OCUP="2651" if CNO=="2931"
	replace OCUP="2652" if CNO=="2932"
	replace OCUP="2653" if CNO=="2933"
	replace OCUP="2654" if CNO=="2934"
	replace OCUP="2655" if CNO=="2935"
	replace OCUP="2656" if CNO=="2936"
	replace OCUP="2659" if CNO=="2937"
	replace OCUP="2659" if CNO=="2939"
	replace OCUP="3118" if CNO=="3110"
	replace OCUP="3111" if CNO=="3121"
	replace OCUP="3112" if CNO=="3122"
	replace OCUP="3113" if CNO=="3123"
	replace OCUP="3114" if CNO=="3124"
	replace OCUP="3114" if CNO=="3125"
	replace OCUP="3115" if CNO=="3126"
	replace OCUP="3116" if CNO=="3127"
	replace OCUP="3117" if CNO=="3128"
	replace OCUP="3119" if CNO=="3129"
	replace OCUP="3131" if CNO=="3131"
	replace OCUP="3132" if CNO=="3132"
	replace OCUP="3133" if CNO=="3133"
	replace OCUP="3134" if CNO=="3134"
	replace OCUP="3135" if CNO=="3135"
	replace OCUP="3139" if CNO=="3139"
	replace OCUP="3141" if CNO=="3141"
	replace OCUP="3142" if CNO=="3142"
	replace OCUP="3143" if CNO=="3143"
	replace OCUP="3151" if CNO=="3151"
	replace OCUP="3152" if CNO=="3152"
	replace OCUP="3153" if CNO=="3153"
	replace OCUP="3154" if CNO=="3154"
	replace OCUP="3155" if CNO=="3155"
	replace OCUP="3115" if CNO=="3160"
	replace OCUP="3114" if CNO=="3160"
	replace OCUP="3111" if CNO=="3160"
	replace OCUP="3112" if CNO=="3160"
	replace OCUP="3113" if CNO=="3160"
	replace OCUP="3116" if CNO=="3160"
	replace OCUP="3119" if CNO=="3160"
	replace OCUP="3117" if CNO=="3160"
	replace OCUP="3121" if CNO=="3201"
	replace OCUP="3123" if CNO=="3202"
	replace OCUP="3122" if CNO=="3203"
	replace OCUP="3122" if CNO=="3204"
	replace OCUP="3122" if CNO=="3205"
	replace OCUP="3122" if CNO=="3206"
	replace OCUP="3122" if CNO=="3207"
	replace OCUP="3122" if CNO=="3209"
	replace OCUP="3211" if CNO=="3311"
	replace OCUP="3211" if CNO=="3312"
	replace OCUP="3212" if CNO=="3313"
	replace OCUP="3212" if CNO=="3314"
	replace OCUP="3214" if CNO=="3315"
	replace OCUP="3214" if CNO=="3316"
	replace OCUP="3214" if CNO=="3317"
	replace OCUP="3251" if CNO=="3321"
	replace OCUP="3252" if CNO=="3322"
	replace OCUP="3259" if CNO=="3323"
	replace OCUP="3254" if CNO=="3324"
	replace OCUP="3255" if CNO=="3325"
	replace OCUP="3257" if CNO=="3326"
	replace OCUP="3240" if CNO=="3327"
	replace OCUP="3259" if CNO=="3329"
	replace OCUP="2230" if CNO=="3331"
	replace OCUP="3230" if CNO=="3331"
	replace OCUP="3230" if CNO=="3339"
	replace OCUP="3311" if CNO=="3401"
	replace OCUP="3312" if CNO=="3402"
	replace OCUP="3313" if CNO=="3403"
	replace OCUP="3314" if CNO=="3404"
	replace OCUP="3315" if CNO=="3405"
	replace OCUP="3322" if CNO=="3510"
	replace OCUP="3321" if CNO=="3521"
	replace OCUP="3323" if CNO=="3522"
	replace OCUP="3324" if CNO=="3523"
	replace OCUP="3331" if CNO=="3531"
	replace OCUP="3332" if CNO=="3532"
	replace OCUP="3333" if CNO=="3533"
	replace OCUP="3334" if CNO=="3534"
	replace OCUP="3339" if CNO=="3535"
	replace OCUP="3339" if CNO=="3539"
	replace OCUP="3341" if CNO=="3611"
	replace OCUP="3342" if CNO=="3612"
	replace OCUP="3343" if CNO=="3613"
	replace OCUP="3344" if CNO=="3614"
	replace OCUP="3352" if CNO=="3621"
	replace OCUP="3353" if CNO=="3622"
	replace OCUP="3354" if CNO=="3623"
	replace OCUP="3359" if CNO=="3629"
	replace OCUP="3355" if CNO=="3631"
	replace OCUP="3355" if CNO=="3632"
	replace OCUP="3411" if CNO=="3711"
	replace OCUP="3411" if CNO=="3712"
	replace OCUP="3412" if CNO=="3713"
	replace OCUP="3412" if CNO=="3714"
	replace OCUP="3412" if CNO=="3715"
	replace OCUP="3413" if CNO=="3716"
	replace OCUP="3421" if CNO=="3721"
	replace OCUP="3422" if CNO=="3722"
	replace OCUP="3423" if CNO=="3723"
	replace OCUP="3423" if CNO=="3724"
	replace OCUP="3431" if CNO=="3731"
	replace OCUP="3432" if CNO=="3732"
	replace OCUP="3433" if CNO=="3733"
	replace OCUP="3434" if CNO=="3734"
	replace OCUP="3435" if CNO=="3739"
	replace OCUP="3511" if CNO=="3811"
	replace OCUP="3512" if CNO=="3812"
	replace OCUP="3513" if CNO=="3813"
	replace OCUP="3514" if CNO=="3814"
	replace OCUP="3512" if CNO=="3820"
	replace OCUP="3521" if CNO=="3831"
	replace OCUP="3521" if CNO=="3832"
	replace OCUP="3522" if CNO=="3833"
	replace OCUP="4311" if CNO=="4111"
	replace OCUP="4313" if CNO=="4112"
	replace OCUP="4312" if CNO=="4113"
	replace OCUP="4321" if CNO=="4121"
	replace OCUP="4322" if CNO=="4122"
	replace OCUP="4323" if CNO=="4123"
	replace OCUP="4411" if CNO=="4210"
	replace OCUP="4415" if CNO=="4210"
	replace OCUP="4412" if CNO=="4221"
	replace OCUP="4413" if CNO=="4222"
	replace OCUP="4416" if CNO=="4223"
	replace OCUP="4132" if CNO=="4301"
	replace OCUP="4131" if CNO=="4301"
	replace OCUP="4419" if CNO=="4309"
	replace OCUP="4110" if CNO=="4309"
	replace OCUP="4120" if CNO=="4309"
	replace OCUP="4225" if CNO=="4411"
	replace OCUP="4226" if CNO=="4412"
	replace OCUP="4221" if CNO=="4421"
	replace OCUP="4224" if CNO=="4422"
	replace OCUP="4223" if CNO=="4423"
	replace OCUP="4222" if CNO=="4424"
	replace OCUP="4227" if CNO=="4430"
	replace OCUP="4211" if CNO=="4441"
	replace OCUP="4212" if CNO=="4442"
	replace OCUP="4212" if CNO=="4443"
	replace OCUP="4213" if CNO=="4444"
	replace OCUP="4214" if CNO=="4445"
	replace OCUP="4211" if CNO=="4446"
	replace OCUP="4229" if CNO=="4500"
	replace OCUP="5212" if CNO=="5000"
	replace OCUP="5132" if CNO=="5000"
	replace OCUP="5131" if CNO=="5000"
	replace OCUP="5120" if CNO=="5000"
	replace OCUP="5246" if CNO=="5000"
	replace OCUP="5120" if CNO=="5110"
	replace OCUP="5131" if CNO=="5120"
	replace OCUP="5246" if CNO=="5120"
	replace OCUP="5132" if CNO=="5120"
	replace OCUP="5212" if CNO=="5120"
	replace OCUP="5222" if CNO=="5210"
	replace OCUP="5223" if CNO=="5220"
	replace OCUP="5221" if CNO=="5300"
	replace OCUP="5211" if CNO=="5411"
	replace OCUP="5211" if CNO=="5412"
	replace OCUP="5244" if CNO=="5420"
	replace OCUP="5245" if CNO=="5430"
	replace OCUP="5243" if CNO=="5491"
	replace OCUP="5242" if CNO=="5492"
	replace OCUP="5241" if CNO=="5493"
	replace OCUP="5249" if CNO=="5499"
	replace OCUP="5230" if CNO=="5500"
	replace OCUP="5321" if CNO=="5611"
	replace OCUP="5321" if CNO=="5612"
	replace OCUP="3213" if CNO=="5621"
	replace OCUP="3258" if CNO=="5622"
	replace OCUP="5329" if CNO=="5629"
	replace OCUP="5322" if CNO=="5710"
	replace OCUP="5312" if CNO=="5721"
	replace OCUP="5311" if CNO=="5721"
	replace OCUP="5311" if CNO=="5722"
	replace OCUP="5141" if CNO=="5811"
	replace OCUP="5142" if CNO=="5812"
	replace OCUP="5111" if CNO=="5821"
	replace OCUP="5112" if CNO=="5822"
	replace OCUP="5113" if CNO=="5823"
	replace OCUP="5113" if CNO=="5824"
	replace OCUP="5113" if CNO=="5825"
	replace OCUP="5151" if CNO=="5831"
	replace OCUP="5152" if CNO=="5832"
	replace OCUP="5153" if CNO=="5833"
	replace OCUP="5152" if CNO=="5840"
	replace OCUP="5162" if CNO=="5891"
	replace OCUP="5163" if CNO=="5892"
	replace OCUP="5164" if CNO=="5893"
	replace OCUP="5165" if CNO=="5894"
	replace OCUP="5161" if CNO=="5895"
	replace OCUP="5169" if CNO=="5899"
	replace OCUP="3351" if CNO=="5910"
	replace OCUP="5412" if CNO=="5910"
	replace OCUP="3351" if CNO=="5921"
	replace OCUP="5412" if CNO=="5921"
	replace OCUP="5412" if CNO=="5922"
	replace OCUP="5412" if CNO=="5923"
	replace OCUP="5411" if CNO=="5931"
	replace OCUP="5411" if CNO=="5932"
	replace OCUP="5414" if CNO=="5941"
	replace OCUP="5414" if CNO=="5942"
	replace OCUP="5413" if CNO=="5991"
	replace OCUP="5419" if CNO=="5992"
	replace OCUP="5419" if CNO=="5993"
	replace OCUP="5419" if CNO=="5999"
	replace OCUP="6114" if CNO=="6110"
	replace OCUP="6111" if CNO=="6110"
	replace OCUP="6112" if CNO=="6110"
	replace OCUP="6113" if CNO=="6120"
	replace OCUP="6121" if CNO=="6201"
	replace OCUP="6121" if CNO=="6202"
	replace OCUP="6121" if CNO=="6203"
	replace OCUP="6123" if CNO=="6204"
	replace OCUP="6122" if CNO=="6205"
	replace OCUP="6129" if CNO=="6205"
	replace OCUP="6121" if CNO=="6209"
	replace OCUP="6129" if CNO=="6209"
	replace OCUP="6130" if CNO=="6300"
	replace OCUP="6210" if CNO=="6410"
	replace OCUP="6221" if CNO=="6421"
	replace OCUP="6222" if CNO=="6422"
	replace OCUP="6223" if CNO=="6423"
	replace OCUP="6224" if CNO=="6430"
	replace OCUP="7114" if CNO=="7111"
	replace OCUP="7114" if CNO=="7112"
	replace OCUP="7112" if CNO=="7121"
	replace OCUP="7111" if CNO=="7121"
	replace OCUP="7113" if CNO=="7122"
	replace OCUP="7115" if CNO=="7131"
	replace OCUP="7115" if CNO=="7132"
	replace OCUP="7119" if CNO=="7191"
	replace OCUP="7119" if CNO=="7192"
	replace OCUP="7119" if CNO=="7193"
	replace OCUP="7119" if CNO=="7199"
	replace OCUP="7123" if CNO=="7211"
	replace OCUP="7123" if CNO=="7212"
	replace OCUP="7126" if CNO=="7221"
	replace OCUP="7126" if CNO=="7222"
	replace OCUP="7126" if CNO=="7223"
	replace OCUP="7131" if CNO=="7231"
	replace OCUP="7132" if CNO=="7231"
	replace OCUP="7131" if CNO=="7232"
	replace OCUP="7132" if CNO=="7232"
	replace OCUP="7122" if CNO=="7240"
	replace OCUP="7127" if CNO=="7250"
	replace OCUP="7121" if CNO=="7291"
	replace OCUP="7124" if CNO=="7292"
	replace OCUP="7125" if CNO=="7293"
	replace OCUP="7126" if CNO=="7294"
	replace OCUP="7133" if CNO=="7295"
	replace OCUP="7211" if CNO=="7311"
	replace OCUP="7212" if CNO=="7312"
	replace OCUP="7213" if CNO=="7313"
	replace OCUP="7214" if CNO=="7314"
	replace OCUP="7215" if CNO=="7315"
	replace OCUP="7221" if CNO=="7321"
	replace OCUP="7222" if CNO=="7322"
	replace OCUP="7223" if CNO=="7323"
	replace OCUP="7224" if CNO=="7324"
	replace OCUP="7231" if CNO=="7401"
	replace OCUP="7232" if CNO=="7402"
	replace OCUP="7233" if CNO=="7403"
	replace OCUP="7233" if CNO=="7404"
	replace OCUP="7234" if CNO=="7405"
	replace OCUP="7411" if CNO=="7510"
	replace OCUP="7412" if CNO=="7521"
	replace OCUP="7413" if CNO=="7522"
	replace OCUP="7421" if CNO=="7531"
	replace OCUP="7421" if CNO=="7532"
	replace OCUP="7422" if CNO=="7533"
	replace OCUP="7311" if CNO=="7611"
	replace OCUP="7312" if CNO=="7612"
	replace OCUP="7313" if CNO=="7613"
	replace OCUP="7314" if CNO=="7614"
	replace OCUP="7315" if CNO=="7615"
	replace OCUP="7316" if CNO=="7616"
	replace OCUP="7317" if CNO=="7617"
	replace OCUP="7318" if CNO=="7618"
	replace OCUP="7319" if CNO=="7619"
	replace OCUP="7321" if CNO=="7621"
	replace OCUP="7322" if CNO=="7622"
	replace OCUP="7323" if CNO=="7623"
	replace OCUP="7511" if CNO=="7701"
	replace OCUP="7511" if CNO=="7702"
	replace OCUP="7512" if CNO=="7703"
	replace OCUP="7513" if CNO=="7704"
	replace OCUP="7514" if CNO=="7705"
	replace OCUP="7514" if CNO=="7706"
	replace OCUP="7514" if CNO=="7707"
	replace OCUP="7516" if CNO=="7708"
	replace OCUP="7515" if CNO=="7709"
	replace OCUP="7521" if CNO=="7811"
	replace OCUP="7523" if CNO=="7812"
	replace OCUP="7522" if CNO=="7820"
	replace OCUP="7531" if CNO=="7831"
	replace OCUP="7532" if CNO=="7832"
	replace OCUP="7532" if CNO=="7833"
	replace OCUP="7533" if CNO=="7834"
	replace OCUP="7534" if CNO=="7835"
	replace OCUP="7535" if CNO=="7836"
	replace OCUP="7536" if CNO=="7837"
	replace OCUP="7541" if CNO=="7891"
	replace OCUP="7542" if CNO=="7892"
	replace OCUP="7543" if CNO=="7893"
	replace OCUP="7544" if CNO=="7894"
	replace OCUP="7549" if CNO=="7899"
	replace OCUP="8111" if CNO=="8111"
	replace OCUP="8112" if CNO=="8112"
	replace OCUP="8113" if CNO=="8113"
	replace OCUP="8114" if CNO=="8114"
	replace OCUP="8121" if CNO=="8121"
	replace OCUP="8122" if CNO=="8122"
	replace OCUP="8131" if CNO=="8131"
	replace OCUP="8131" if CNO=="8132"
	replace OCUP="8132" if CNO=="8133"
	replace OCUP="8141" if CNO=="8141"
	replace OCUP="8142" if CNO=="8142"
	replace OCUP="8143" if CNO=="8143"
	replace OCUP="8172" if CNO=="8144"
	replace OCUP="8171" if CNO=="8145"
	replace OCUP="8151" if CNO=="8151"
	replace OCUP="8152" if CNO=="8152"
	replace OCUP="8153" if CNO=="8153"
	replace OCUP="8154" if CNO=="8154"
	replace OCUP="8155" if CNO=="8155"
	replace OCUP="8156" if CNO=="8156"
	replace OCUP="8159" if CNO=="8159"
	replace OCUP="8160" if CNO=="8160"
	replace OCUP="8157" if CNO=="8170"
	replace OCUP="8181" if CNO=="8191"
	replace OCUP="8182" if CNO=="8192"
	replace OCUP="8183" if CNO=="8193"
	replace OCUP="8189" if CNO=="8199"
	replace OCUP="8211" if CNO=="8201"
	replace OCUP="8212" if CNO=="8202"
	replace OCUP="8219" if CNO=="8209"
	replace OCUP="8311" if CNO=="8311"
	replace OCUP="8312" if CNO=="8312"
	replace OCUP="8341" if CNO=="8321"
	replace OCUP="8341" if CNO=="8322"
	replace OCUP="8342" if CNO=="8331"
	replace OCUP="8343" if CNO=="8332"
	replace OCUP="8344" if CNO=="8333"
	replace OCUP="8350" if CNO=="8340"
	replace OCUP="8322" if CNO=="8411"
	replace OCUP="8322" if CNO=="8412"
	replace OCUP="8331" if CNO=="8420"
	replace OCUP="8332" if CNO=="8431"
	replace OCUP="8332" if CNO=="8432"
	replace OCUP="8321" if CNO=="8440"
	replace OCUP="9111" if CNO=="9100"
	replace OCUP="9112" if CNO=="9210"
	replace OCUP="9121" if CNO=="9221"
	replace OCUP="9122" if CNO=="9222"
	replace OCUP="9123" if CNO=="9223"
	replace OCUP="9129" if CNO=="9229"
	replace OCUP="9412" if CNO=="9310"
	replace OCUP="9411" if CNO=="9320"
	replace OCUP="9520" if CNO=="9410"
	replace OCUP="9510" if CNO=="9420"
	replace OCUP="9621" if CNO=="9431"
	replace OCUP="9621" if CNO=="9432"
	replace OCUP="9621" if CNO=="9433"
	replace OCUP="9623" if CNO=="9434"
	replace OCUP="9611" if CNO=="9441"
	replace OCUP="9612" if CNO=="9442"
	replace OCUP="9613" if CNO=="9443"
	replace OCUP="9622" if CNO=="9490"
	replace OCUP="9629" if CNO=="9490"
	replace OCUP="9211" if CNO=="9511"
	replace OCUP="9214" if CNO=="9512"
	replace OCUP="9212" if CNO=="9520"
	replace OCUP="9213" if CNO=="9530"
	replace OCUP="9216" if CNO=="9541"
	replace OCUP="9216" if CNO=="9542"
	replace OCUP="9215" if CNO=="9543"
	replace OCUP="9312" if CNO=="9601"
	replace OCUP="9313" if CNO=="9602"
	replace OCUP="9311" if CNO=="9603"
	replace OCUP="9329" if CNO=="9700"
	replace OCUP="9321" if CNO=="9700"
	replace OCUP="9331" if CNO=="9811"
	replace OCUP="9332" if CNO=="9811"
	replace OCUP="9333" if CNO=="9811"
	replace OCUP="9331" if CNO=="9812"
	replace OCUP="9332" if CNO=="9812"
	replace OCUP="9334" if CNO=="9820"
	}

	drop OCUPACION

	* Drop transfers within the same FIRM
	*---------------------------------------------------------------------------
	bys ID_ANONIM workplace: gen n=_n

	drop if n>1

	drop n

	* Merge the FUA dataset
	*---------------------------------------------------------------------------
	sort MUNICIPIO_CC

	merge m:1 MUNICIPIO_CC using  "$input\maps\FuaX maps.dta",keepusing(fua fuax nuts_3 MUNICIPIO_NAME) keep(3) nogen
	
	rename nuts_3 NUTS_3

		** Create province
		tostring MUNICIPIO_CC,gen(s_MUNI)
		gen prov=real(substr(s_MUNI,1,1)) if length(s_MUNI)<5

		replace prov=real(substr(s_MUNI,1,2)) if length(s_MUNI)==5

	* Formatting, labelling and saving results in an intermediate folder
	*---------------------------------------------------------------------------

	* Formatting
	destring CNAE_CC,replace

	* Labelling
	ren (ID_ANONIM workplace fuax NUTS_3 fua) (i j fua1 fua2 fua3)

	label var fua1 "Mixed FUAs + NUTS3"
	label var fua2 "NUTS3"
	label var fua3 "Functional Urban Area"
	label var i "Person"
	label var j "Workplace"
	label var t "Year-Month"
	label var OCUP "CISCO-4"
	label var DATE_END "End of contract (fixed or long term)"
	label var DATE_END_ft "End of contract (fixed)"
	label var DATE_BEGIN "Begin of contract"
	label var contracts_num "Num contracts within the same month"

	drop *_INICIO *_TERMINO

	sort i j t	
	compress
	save "$intermediate_files/data_`year'.dta",replace
	}
	
************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
