********************************************************************************
* Title: 03. Consolidate contracts data.do
* Description: This dofile consolidates the contracts data in two steps: First, 
* it collapses the information by year to have it in annual terms. Second, it defines
* the Local Labour Markets (LLM).
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* B. Log
********************************************************************************

	cap log close
	cap log using "$logs\03. Consolidate contracts data $date.log",replace

********************************************************************************
* C. Load and prepare the data
********************************************************************************
	
	* Load and append the data
	*---------------------------------------------------------------------------
	use "$intermediate_files\data_2009",clear
	
		forval year=2010/2017 {
			cap append using "$intermediate_files\data_`year'"
		}
		
		** Checks
		assert !mi(t) if !mi(DATE_BEGIN)
		assert i != "000000000000"
	
	* Generate a numeric correspondence
	*---------------------------------------------------------------------------
		foreach var in i j IDENT_CC fua1 fua2 fua3 {
		
			egen `var'_num=group(`var')
			
			cap replace `var'_num=. if `var'==.			
			cap replace `var'_num="" if length(`var')==0
			
			rename `var' `var'_s		
			rename `var'_num `var'
		
				if "`var'"=="i" {
				label var `var' "worker"
				}
				
				if "`var'"=="j" {
				label var `var' "Firm"
				}
				
				if "`var'"=="IDENT_CC" {
				label var `var' "Firm x Municipality"
				}
				
				if "`var'"=="fua1" {
				label var `var' "Mixed FUAs"
				}
				
				if "`var'"=="fua2" {
				label var `var' "nuts 3"
				}
	
				if "`var'"=="fua3" {
				label var `var' "FUA"
				}	
	
		preserve
		
			keep `var' `var'_s
			
			duplicates drop
			sort `var'
			
			save "$intermediate_files\\`var'",replace
			
		restore
		}	
	
		** Make string variables numeric 
		destring OCUP CNO ,replace		
		drop s_MUNI 
		
	* Define new hires
	*---------------------------------------------------------------------------
	/*
	*	In ESP: new hires are those who start a contract with an establishment in year 
	* t, but have not started a contract with the same firm (or firmXmunicipality) 
	* in year t-1 and their expected contract duration (including renewals) was 
	* either indefinite or: i) at least one month; and ii) up to December of year t
	*/
	
		** At firm level
		sort i j t DATE_BEGIN

			*** Define first the period between observations		
			bys i j:gen period=t-t[_n-1] if !missing(t[_n-1]) & !missing(t)
		
			*** Now define new hires based on first appareance and with >30 days or with more than 12m since the last contract with the same firm
		
				bys i j: gen nnn=_n
				gen one=(nnn==1 & dur>=30) 
				replace one=1 if nnn>1 & dur>=30 & period>12

		*** At Firm X Municipality level
		cap drop nnn period

			sort i IDENT_CC t DATE_BEGIN
		
			** Define first the period between observations	
				bys i IDENT_CC:gen period=t-t[_n-1] if !missing(t[_n-1]) & !missing(t)
				bys i IDENT_CC: gen nnn=_n
				
				gen one_cc2=(nnn==1 & dur>=30) 
				replace one_cc2=1 if nnn>1 & dur>=30 & period>12
				drop nnn period 
	
	* Keep relevant period (2010 - 2017)
	*---------------------------------------------------------------------------
	keep if inrange(year(dofm(t)),2010,2017)

	* Prepare number of hours worked variable
	*---------------------------------------------------------------------------
	replace HORAS=HORAS/100 /*The variable is defined in hundred of hours*/
	replace HORAS=40 if HORAS>40 /* We bound contract hours to avoid outliers */

		** Paste the type of contract
		sort CODIGO_CONT
		merge m:1 CODIGO_CONT using "$raw\TEHTPCTO.dta", keep(1 3) nogen /*TEHTPCTO is the dta version of TEHTPCTO.txt. This file is provided in the Contracts data and contains the names of the type of contracts.*/
	
	* Exclude specific sectors from the sample
	*---------------------------------------------------------------------------
	/*	
		NACE 05-82, arts (90), entertainment (92), recreation (93), associations (94), 
		*repair (95) and personal services including hairdressing or laundries (96). 
		*We exclude self-employed and household employees.
	*/
	destring CNAE_CC,replace
	keep if inrange(CNAE_CC,5,82)|CNAE_CC==90|CNAE_CC==92|CNAE_CC==93|CNAE_CC==94|CNAE_CC==95|CNAE_CC==96
	
	* Generate additional variables
	*---------------------------------------------------------------------------

		** Generate 2 and 3-digit ISCO
		gen OCUP_str = string(OCUP)
		replace OCUP_str = "0" + OCUP_str if length(OCUP_str) == 3
		assert length(OCUP_str) == 4
		
		gen OCUP_1D = real(substr(OCUP_str, 1, 1))
		gen OCUP_2D = real(substr(OCUP_str, 1, 2))
		gen OCUP_3D = real(substr(OCUP_str, 1, 3))	
		
		drop OCUP_str
	
		** Generate level of skills
		gen skills = 1 if inrange(OCUP_1D, 0, 3)
		replace skills = 2 if inlist(OCUP_1D, 4, 6, 7, 8)
		replace skills = 3 if inlist(OCUP_1D, 5, 9)
		
		label define skills 1 "High skill" 2 "Med skill" 3 "Low skill"
		label values skills skills 

********************************************************************************
* D. Collapse the data at year level
********************************************************************************

	gen year=year(dofm(t))

	// Variables to keep within the same FirmXmunicipality: We follow two conditions:	
		*(1) If during year t, there is new and not new hires, we keep info from the former
		*(2) If during year t, there is no new hires (see conditions above) we keep 
		*info of the first and last contract of that year
	
		foreach var in one one_cc2 {
			bys i IDENT_CC year: egen min_`var'=min(`var')	
			bys i IDENT_CC year: egen max_`var'=max(`var')
		}	
	
	
	foreach var in s_MUNI j IDENT_CC CNO HORAS CODIGO_CONT DATE_END DATE_BEGIN /*
	*/ MUNICIPIO_CENTRO    /*
	*/  CNAE_CC MUNICIPIO_CC prov fua1 fua2 fua3 {
	
		cap replace `var'=. if (one!=1|one_cc2!=1) & max_one_cc2!=min_one_cc2 	
		cap replace `var'="" if (one!=1|one_cc2!=1) & max_one_cc2!=min_one_cc2 	
	}
	
	drop if missing(j)|missing(IDENT_CC)
		
	keep skills OCUP* j CNO one one_cc2 HORAS CODIGO_CONT DATE_END DATE_BEGIN ///
		NIVEL_FORMA  MUNICIPIO_CENTRO MUNICIPIO_PF PAIS_RESID_PF NACIONALIDAD_PF ///
		women ANO_NAC EDAD CNAE_CC MUNICIPIO_CC prov fua1 fua2 fua3 i IDENT_CC ///
		year

	collapse (max) skills OCUP* j CNO one one_cc2 HORAS CODIGO_CONT DATE_END ///
		(min) DATE_BEGIN NIVEL_FORMA  MUNICIPIO_CENTRO MUNICIPIO_PF PAIS_RESID_PF ///
		NACIONALIDAD_PF women ANO_NAC EDAD CNAE_CC MUNICIPIO_CC prov fua1 fua2 fua3 ///
		, by(i IDENT_CC year)
	
	* Put missing on contracts that lasted <30 days
	replace one=. if DATE_END-DATE_BEGIN<30
	replace one_cc2=. if DATE_END-DATE_BEGIN<30

********************************************************************************
* E. Define the local labor markets
********************************************************************************

	cap drop market*
	forval x=1/3 {

		egen market1_`x' =group(fua`x' OCUP)
		egen market2_`x' =group(fua`x' OCUP_2D)

		label var market1_`x' "Labor market (fua`x' x isco-4)"
		label var market2_`x' "Labor market (fua`x' x isco-2)"
		
		forval y = 1/2 {
			replace market`y'_`x' =. if mi(fua`x')
	}
		
		replace market2_`x' =. if mi(OCUP_2D)
	}
	
	* Export correspondence of labor markets
		
		** At occupation level
		forval x=1/3 {
			preserve
			
				keep fua`x' OCUP market1_`x'
				gduplicates drop fua`x' OCUP,force

				drop if mi(fua`x') | OCUP == .

				sort market1_`x'
				save "$intermediate_files\market1_`x'_correspondence",replace
			restore 
			}
	
		** At 2-digit ocupation level
		forval x=1/3 {
		preserve
		
			keep fua`x' OCUP_2D market2_`x'
			gduplicates drop fua`x' OCUP_2D,force
			
			drop if mi(fua`x')|OCUP_2D==.

			sort market2_`x'
			save "$intermediate_files\market3_`x'_correspondence",replace
		restore 
		}				
	
	* Replace the file  which now contains the definition of the LLMs
	save "$input\collapse_by_year",replace

********************************************************************************
* F. Generate a random sample of workers using the masters data
********************************************************************************
	
	if $random_sample == 1 {
	
		cd "$input"
		use "collapse_by_year",clear

		*Filter and keep contracts from 2010 to 2017
		keep if inrange(year,2010,2017)
		
		**Work with a random sample
		
		**Random Sample
		preserve
			keep i
			bys i: keep if _n==1
			set seed 4321
			gen sort=uniform()
			sort sort
			gen i_random=_n
			sort i
			drop sort
			
			save random.dta,replace
		restore
		
		sort i
		merge i using random
		drop _merge

		*Save 5% number
		qui sum i_random
		local max=r(max)
		local div=0.01*$sample_size
		local sample=`div'*`max'
		
		keep if i_random>0 & i_random<`sample'

		*Save file
		save data_sample,replace	
	}
	
********************************************************************************
* G. Generate additional variables for analysis
********************************************************************************
	
	use "$input\data_sample", clear
	
	* Additional variables for analysis
	*---------------------------------------------------------------------------
	
		* Long term contract: -> TYPE OF CONTRACT AS "INDEFINIDO"	
		gen ltemp=(CODIGO_CONT<300&CODIGO_CONT!=2 & (CODIGO_CONT<4|CODIGO_CONT>7) & /*
		*/ CODIGO_CONT!=10 & (CODIGO_CONT<14|CODIGO_CONT>19) & CODIGO_CONT!=22 & /*
		*/ (CODIGO_CONT<24|CODIGO_CONT>45) & CODIGO_CONT!=85 & CODIGO_CONT!=87 & /*
		*/ CODIGO_CONT!=90 & CODIGO_CONT!=95) if CODIGO_CONT!=.

		* Industry fe
		gen industry=CNAE_CC
		
		* Education
		gen education=1 if NIVEL_FORMA==80|NIVEL_FORMA==11|NIVEL_FORMA==12|NIVEL_FORMA==22|NIVEL_FORMA==23
		replace education=2 if NIVEL_FORMA==32|NIVEL_FORMA==33|NIVEL_FORMA==34|NIVEL_FORMA==41|NIVEL_FORMA==51|NIVEL_FORMA==52|NIVEL_FORMA==53
		replace education=3 if 	NIVEL_FORMA==54|NIVEL_FORMA==59|NIVEL_FORMA==60|NIVEL_FORMA==61|NIVEL_FORMA==57|NIVEL_FORMA==55|NIVEL_FORMA==56|NIVEL_FORMA==58
		replace education=4 if missing(NIVEL_FORMA)

		label define education 1 "< Upper secondary" 2 "Upper secondary" 3 "Tertiary" 4 "Missing"			
		label values education education 
			
		tab education,gen(d_educ)
	
		* Age
		gen age=EDAD 
		
		* Firm x Municipality FE
		egen fe_cc2=group(IDENT_CC)
		
		* Worker fixed effects
		egen id=group(i)
		
		* Clustering of errors -> LLM x Year
		egen cluster1=group(market1_1 year)
		egen cluster2=group(market1_2 year)
		egen cluster3=group(market1_3 year)

		* FE
		egen firmXmunXyear=group(IDENT_CC year)

		* Dummy for having started any type of contract the year before
		sort i year
		gen dum_fix_t_1=(i==i[_n-1] & year-year[_n-1]==1)

		* Full time vs part time dummy
		cd "$input"
		
			** First, match with the type of contract (constructed using the contract description)
			sort CODIGO_CONT
			merge m:1 CODIGO_CONT using "$raw\FTPT_CONTRATOS_CONV.dta", keep(1 3) nogen /*FTPT_CONTRATOS_CONV is a file provided 
			in the contracts data with the codes and description of the type of contract. We constructed a dta with the indicator of full-time contracts.*/

		gen FTPT=(ftpt==1|ftpt==2) // 1 and 2 when the contract is at full time

	* Drop cases in which individuals are hired for less than 30 days
	drop if DATE_END-DATE_BEGIN<30

	* Generate dependent variables
	*---------------------------------------------------------------------------
	gen y_1=0 if one_cc2==1
	replace y_1=1 if y_1==0 & ltemp==1 // y_1 0 "Temporal" 1 "Permanent"
	label var y_1 "Permanent contract"
		
	sort i IDENT_CC year

	gen y_2=0 if one_cc2==1 & ltemp==0		
	replace y_2=1 if y_2==0 & i==i[_n+1] & (year[_n+1]-year)==1 & IDENT_CC==IDENT_CC[_n+1] & ltemp[_n+1]==1
	label var y_2 "Conversion"		
		
	save "$input\data_sample", replace		

************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
